API Version: 1
Library Version: 1.5.0
Generated by gi-docgen 2026.1
enum Adap.ToastPriority
AdapToast behavior when another toast is already displayed.
AdapToast
ADAP_TOAST_PRIORITY_NORMAL
The toast will be queued if another toast is already displayed.
0
ADAP_TOAST_PRIORITY_HIGH
The toast will be displayed immediately, pushing the previous toast into the queue instead.
1
Content