Enumeration
AdapToolbarStyle
since: 1.4
Description [src]
Describes the possible top or bottom bar styles in an AdapToolbarView widget.
ADAP_TOOLBAR_FLAT is suitable for simple content, such as
AdapStatusPage or AdapPreferencesPage, where the background at the
top and bottom parts of the page is uniform. Additionally, windows with
sidebars should always use this style.
ADAP_TOOLBAR_RAISED style is suitable for content such as
utility panes,
where some elements are directly adjacent to the top/bottom bars, or
AdapTabView, where each page can have a different background.
ADAP_TOOLBAR_RAISED_BORDER style is similar to ADAP_TOOLBAR_RAISED, but
with the shadow replaced with a more subtle border. It’s intended to be used
in applications like image viewers, where a shadow over the content might be undesired.
See AdapToolbarView:top-bar-style and
AdapToolbarView:bottom-bar-style.
New values may be added to this enumeration over time.
Available since: 1.4